pub struct CUpdateAttributes {
pub entity_id: i32,
pub attributes: Vec<AttributeSnapshot>,
}Expand description
Clientbound packet sent to update entity attributes and their modifiers.
Used for things like sprint speed modifiers, potion effects on speed/health, etc.
Vanilla: ClientboundUpdateAttributesPacket
Fields
entity_id: i32The entity ID whose attributes are being updated.
attributes: Vec<AttributeSnapshot>The attribute snapshots to sync.
Implementations
Sourceimpl CUpdateAttributes
impl CUpdateAttributes
Sourcepub const fn new(entity_id: i32, attributes: Vec<AttributeSnapshot>) -> Self
pub const fn new(entity_id: i32, attributes: Vec<AttributeSnapshot>) -> Self
Creates a new update attributes packet.